@@ -14,6 +14,7 @@ import shutil
 import string
 import sys
 import tempfile
+import textwrap
 
 
 def random_token(length, chrs, random=random.SystemRandom()):
@@ -47,6 +48,7 @@ class CreateProjectTemplate(object):
                 call_command('startproject', self.temp_project_basename)
                 shutil.copytree(self.temp_project_path, os.path.join(self.template_path, 'files'))
                 self.modify_files()
+                self.add_blank_hooks()
             finally:
                 shutil.rmtree(self.temp_project_path)
         finally:
@@ -65,6 +67,38 @@ class CreateProjectTemplate(object):
         source = self.replace_secret_key(source)
         return source
     
+    def add_blank_hooks(self):
+        hooks_source = textwrap.dedent('''
+            def post_create():
+                """
+                This hook is called after a project is created.
+
+                Your current path is the project's directory.
+
+                Django should be configured, unless you've changed your settings layout -
+                if so, you need to set os.environ['DJANGO_SETTINGS_MODULE']
+
+                Example post_create():
+
+                    >>> def post_create():
+                    ...     from django.core.management import call_command
+                    ...     import subprocess
+                    ...
+                    ...     # Initialise git, make an initial commit
+                    ...     subprocess.call(['git', 'init'])
+                    ...     subprocess.call(['git', 'add', '*.py', '*.txt'])
+                    ...     subprocess.call(['git', 'commit', '-m', 'Initial commit'])
+                    ...
+                    ...     # Run syncdb (your template must have working database settings)
+                    ...     call_command('syncdb', interactive=False)
+
+                """
+
+                pass
+        ''').strip()
+        
+        open(os.path.join(self.template_path, 'hooks.py'), 'w').write(hooks_source)
+    
     def replace_project_name(self, source):
         return source.replace(self.temp_project_basename, '{{ project_name }}')
     
